Git-Url: 
http://git.frugalware.org/gitweb/gitweb.cgi?p=pacman-g2.git;a=commitdiff;h=e6e3d70fb10e4318d2deec7e141cad8fbd7f7f90

commit e6e3d70fb10e4318d2deec7e141cad8fbd7f7f90
Author: Michel Hermier <[email protected]>
Date:   Sat Nov 2 11:31:16 2013 +0100

libpacman: s/parse_descfile/pkginfo_read/ to not confuse with with desc file 
parsing.

diff --git a/lib/libpacman/package.c b/lib/libpacman/package.c
index 22edc84..164f0f9 100644
--- a/lib/libpacman/package.c
+++ b/lib/libpacman/package.c
@@ -142,11 +142,11 @@ int _pacman_pkg_cmp(const void *p1, const void *p2)
return(strcmp(((pmpkg_t *)p1)->name, ((pmpkg_t *)p2)->name));
}

/* Parses the package description file for the current package
*
* Returns: 0 on success, 1 on error
*/
-static int parse_descfile(char *descfile, pmpkg_t *info, int output)
+static int pkginfo_read(char *descfile, pmpkg_t *info, int output)
{
FILE* fp = NULL;
char line[PATH_MAX];
@@ -322,7 +322,7 @@ pmpkg_t *_pacman_pkg_load(const char *pkgfile)
fd = mkstemp(descfile);
archive_read_data_into_fd (archive, fd);
/* parse the info file */
-                       if(parse_descfile(descfile, info, 0) == -1) {
+                       if(pkginfo_read(descfile, info, 0) == -1) {
_pacman_log(PM_LOG_ERROR, _("could not parse the package description file"));
pm_errno = PM_ERR_PKG_INVALID;
unlink(descfile);
@@ -142,11 +142,11 @@ int _pacman_pkg_cmp(const void *p1, const void *p2)
}

-/* Parses the package description file for the current package
+/* Parses the pkginfo package description file for the current package
*
* Returns: 0 on success, 1 on error
_______________________________________________
Frugalware-git mailing list
[email protected]
http://frugalware.org/mailman/listinfo/frugalware-git

Reply via email to